@@ -51,17 +51,18 @@ from requests_toolbelt.multipart.encoder import MultipartEncoder
 config_parser = configparser.ConfigParser()
 config_file = 'config.ini'
 
+
+def set_config_ini_file_full_path(self, config_file: str):
+    """ Sets config file. set_config_ini_file_full_path(config_file= full_path_to/config.ini)"""
+    self.config_file = config_file
+
+
 if not Path(config_file).exists():
     print(
         f'config.ini file ->  {config_file} doesn\'t exist. Please run set_config_ini_file_full_path(config_file=\'full_path_to_config.ini\')')
     sys.exit(1)
 
 
-def set_config_ini_file_full_path(config_file: str):
-    """ Sets config file. set_config_ini_file_full_path(config_file= full_path_to/config.ini)"""
-    config_file = config_file
-
-
 config_parser.read(config_file)
 config = config_parser['test']
 url = config.get('url')
